@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20231130';
+our $VERSION = '0.20231228';
 
-# Table last modified: 2023-11-30
+# Table last modified: 2023-12-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6|78)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|0[25]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|3(?:8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|1[0278]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[369]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|1[0278]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[369]|0[124-8]|8[168]|2[0-469]|6[078]|4[02-49])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|2[235]|0[1-8]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
@@ -153,7 +153,7 @@ our %ZIP_TABLE = (
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
-    '164' => '(?:8(?:6(?:[25]0|66|8[26]|7[78]|1[167]|4[24]|[03][18])|5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|7(?:25|0[15])))',
+    '164' => '(?:8(?:5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
@@ -231,7 +231,7 @@ our %ZIP_TABLE = (
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
     '251' => '(?:8(?:5(?:22|70|4[03]|8[018]|5[0158]|3[0134]|1[0135]|6[067]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[05-8]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|2[0-25]|6[09]|8[025-8]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -390,7 +390,7 @@ our %ZIP_TABLE = (
     '414' => '(?:85(?:11|5[05]))',
     '415' => '(?:(?:8(?:5(?:30|0[125-9]|[12][0-8])|6(?:11|0[23]))|0(?:19[2-4]|392)))',
     '416' => '(?:8(?:5(?:[02]1|77|4[04]|3[03]|5[58])|6(?:60|86|5[04-69])))',
-    '417' => '(?:8(?:5(?:6[05-7]|3[01358]|8[058]|0[135-8]|1[0-29]|5[05]|7[0157]|2[029]|4[035])|6(?:[15]0|32|86|0[19])))',
+    '417' => '(?:8(?:5(?:6[05-7]|3[01358]|1[0-259]|8[058]|0[135-8]|5[05]|7[0157]|2[029]|4[035])|6(?:[15]0|32|86|0[19])))',
     '418' => '(?:(?:86(?:[68]6|01)|0192))',
     '419' => '(?:0(?:19[23]|29[35]|392))',
     '420' => '(?:8(?:6(?:44|50|6[06]|2[02-48]|0[1-468]|8[0158]|7[07]|3[0369]|1[0-268])|5(?:70|2[1378]|1[027]|3[6-8]|8[0158]|6[07]|5[0578]|0[237-9])|7(?:71|0[3469]|3[39]|[12][02]|6[01])))',
@@ -401,12 +401,12 @@ our %ZIP_TABLE = (
     '426' => '(?:(?:8(?:6(?:01|7[07]|3[1-38]|1[27]|4[026]|6[2368])|5(?:39|43|66|1[015]|0[13]|7[057])|7(?:11|22))|0292))',
     '427' => '(?:(?:8(?:5(?:22|41|55|0[12589]|8[18]|1[0-2])|6(?:86|0[12]))|019[356]))',
     '428' => '(?:(?:8(?:6(?:86|5[0-2])|50[1-3])|0192))',
-    '430' => '(?:(?:8(?:6(?:11|20|8[0679]|3[09]|7[0578]|6[578]|5[02-5])|5(?:[246]0|7[057]|5[358]|8[0578]|3[036]|1[01]))|089[78]))',
+    '430' => '(?:(?:8(?:5(?:[246]0|7[057]|5[358]|8[0578]|3[036]|1[01])|6(?:11|20|7[058]|8[0679]|3[09]|6[57]|5[02-5]))|089[78]))',
     '431' => '(?:(?:0(?:49[2-6]|29[258]|19[23]|395)|3(?:19[2-6]|39[23]|492)|1(?:39[2-5]|49[5-7])|(?:22|41)95))',
     '432' => '(?:8(?:5(?:41|80|5[015]|0[178]|3[1279]|2[1-38]|6[12])|6(?:08|11|26|8[06])|777))',
-    '433' => '(?:8(?:5(?:[01]1|67|5[058])|601))',
+    '433' => '(?:8(?:5(?:[01]1|67|5[08])|601))',
     '434' => '(?:8(?:5(?:11|33|50|0[125])|601))',
-    '435' => '(?:8(?:5(?:40|75|3[39]|0[25]|2[02]|6[0178]|8[58]|1[05]|5[1578])|6(?:42|86|1[19]|6[01])))',
+    '435' => '(?:8(?:5(?:[07]5|22|88|3[39]|1[05]|5[1578]|6[078])|6(?:11|42|60|86)))',
     '436' => '(?:8(?:5(?:55|0[1-3])|65[0-3]|701))',
     '437' => '(?:(?:1(?:6(?:9[2-8]|8[68])|19[2-7]|49[2-6]|39[2357]|59[2-4]|292)|8(?:5(?:[45]5|11|0[12])|6(?:[01]1|[68]6))|0(?:29[23]|69[23])))',
     '438' => '(?:(?:8(?:5(?:01|10|43|77|85|5[058])|6(?:[01]1|22|50|86)|71[18])|0(?:19[235]|292)))',
@@ -432,7 +432,7 @@ our %ZIP_TABLE = (
     '458' => '(?:85(?:30|55|8[015]|0[1258]|1[05]|2[0-2]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
     '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|6[067]|7[578]|0[13-9]|4[15])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|[08][1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
-    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-249]|0[13-8]|7[57]|1[12]|4[01])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
+    '461' => '(?:8(?:5(?:41|60|8[0-2568]|2[025]|3[0-249]|0[13-8]|7[57]|1[12]|5[08])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-8]|5[0-24])|710))',
